==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sv-SE/mail.php <==
<?php

return array(
    'a_user_canceled' => 'En användare har avbrutit en artikelförfrågan på webbplatsen',
    'a_user_requested' => 'En användare har efterfrågat en artikel webbplatsen',
    'accessory_name' => 'Tillbehörsnamn:',
    'additional_notes' => 'Ytterligare anmärkningar:',
    'admin_has_created' => 'En administratör har skapat ett konto för dig på: webbsidan.',
    'asset' => 'Tillgång:',
    'asset_name' => 'Tillgångsnamn:',
    'asset_requested' => 'Tillgången begärd',
    'asset_tag' => 'Tillgångstagg:',
    'assigned_to' => 'Tilldelats',
    'best_regards' => 'Vänliga hälsningar,',
    'canceled' => 'Avbruten:',
    'checkin_date' => 'Incheckningsdatum:',
    'checkout_date' => 'Utcheckningsdatum:',
    'click_to_confirm' => 'Vänligen klicka på följande länk för att bekräfta ditt: webbkonto:',
    'click_on_the_link_accessory' => 'Vänligen klicka på länken längst ner för att bekräfta att du har fått tillbehöret.',
    'click_on_the_link_asset' => 'Vänligen klicka på länken längst ner för att bekräfta att du har tagit emot tillgången.',
    'Confirm_Asset_Checkin' => 'Bekräfta incheckning av tillgång',
    'Confirm_Accessory_Checkin' => 'Bekräfta incheckning av tillbehör',
    'Confirm_accessory_delivery' => 'Leveransbekräftelse för tillbehör',
    'Confirm_license_delivery' => 'Leveransbekräftelse för licens',
    'Confirm_asset_delivery' => 'Leveransbekräftelse för tillgång',
    'Confirm_consumable_delivery' => 'Leveransbekräftelse för förbrukningsmaterial',
    'current_QTY' => 'Nuvarande antal',
    'Days' => 'dagar',
    'days' => 'dagar',
    'expecting_checkin_date' => 'Förväntat incheckningsdatum:',
    'expires' => 'Utgår',
    'Expiring_Assets_Report' => 'Rapport över tillgångar med förfallodatum.',
    'Expiring_Licenses_Report' => 'Rapport över licenser med förfallodatum.',
    'hello' => 'Hallå',
    'hi' => 'Hej',
    'i_have_read' => 'Jag har läst och godkänt användarvillkoren och har fått den här produkten.',
    'item' => 'Artikel:',
    'Item_Request_Canceled' => 'Artikelförfrågan annulleras',
    'Item_Requested' => 'Artikel som begärs',
    'link_to_update_password' => 'Vänligen klicka på följande länk för att uppdatera ditt: webblösenord:',
    'login_first_admin' => 'Logga in på din nya Snipe-IT-installation med hjälp av inloggningsuppgifterna nedan:',
    'login' => 'Logga in:',
    'Low_Inventory_Report' => 'Meddelande om lågt lagersaldo',
    'min_QTY' => 'Min. antal',
    'name' => 'namn',
    'new_item_checked' => 'En ny artikel har blivit utcheckad i ditt namn, se detaljer nedan.',
    'password' => 'Lösenord:',
    'password_reset' => 'Lösenordsåterställning',

    'read_the_terms' => 'Läs användarvillkoren nedan.',
    'read_the_terms_and_click' => 'Läs användarvillkoren nedan och klicka på länken längst ner för att bekräfta att du läser och godkänner villkoren för användning och har fått tillgången.',
    'requested' => 'Begärda:',
    'reset_link' => 'Länk för att återställa ditt lösenord',
    'reset_password' => 'Klicka här för att återställa ditt lösenord:',
    'serial' => 'Serienummer',
    'supplier' => 'Leverantör',
    'tag' => 'Tagg',
    'test_email' => 'Testa e-post från Snipe-IT',
    'test_mail_text' => 'Detta är ett test från Snipe-IT Asset Management System. Om du får detta, så fungerar mailen :)',
    'the_following_item' => 'Följande artikel har blivit incheckad: ',
    'low_inventory_alert' => ':count artikel understiger det lägsta tillåtna lagersaldot eller håller på att ta slut.|:count artiklar understiger det lägsta tillåtna lagersaldot eller håller på att ta slut.',
    'assets_warrantee_alert' => 'Garantin för :count tillgång löper ut inom :threshold dagar.|Garantin för :count tillgångar löper ut inom :threshold dagar.',
    'license_expiring_alert' => ':count licens löper ut inom :threshold dagar.|:count licenser löper ut inom :threshold days.',
    'to_reset' => 'För att återställa ditt :web lösenord, fyll i det här formuläret:',
    'type' => 'Typ',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Användare',
    'username' => 'Användarnamn',
    'welcome' => 'Välkommen: namn',
    'welcome_to' => 'Välkommen till: web!',
    'your_credentials' => 'Dina Snipe-IT användaruppgifter',
    'Accessory_Checkin_Notification' => 'Tillbehöret har checkats in',
    'Asset_Checkin_Notification' => 'Tillgången har checkats in',
    'License_Checkin_Notification' => 'Licensen har checkats in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'Visa dina tillgångar'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sv-SE/mail.php <==
<?php

return [
    'a_user_canceled' => 'En användare har avbrutit en artikelförfrågan på webbplatsen',
    'a_user_requested' => 'En användare har efterfrågat en artikel webbplatsen',
    'accessory_name' => 'Tillbehörsnamn:',
    'additional_notes' => 'Ytterligare anmärkningar:',
    'admin_has_created' => 'En administratör har skapat ett konto för dig på: webbsidan.',
    'asset' => 'Tillgång:',
    'asset_name' => 'Tillgångsnamn:',
    'asset_requested' => 'Tillgången begärd',
    'asset_tag' => 'Tillgångstagg',
    'assigned_to' => 'Tilldelats',
    'best_regards' => 'Vänliga hälsningar,',
    'canceled' => 'Avbruten:',
    'checkin_date' => 'Incheckningsdatum:',
    'checkout_date' => 'Utcheckningsdatum:',
    'click_to_confirm' => 'Vänligen klicka på följande länk för att bekräfta ditt: webbkonto:',
    'click_on_the_link_accessory' => 'Vänligen klicka på länken längst ner för att bekräfta att du har fått tillbehöret.',
    'click_on_the_link_asset' => 'Vänligen klicka på länken längst ner för att bekräfta att du har tagit emot tillgången.',
    'Confirm_Asset_Checkin' => 'Bekräfta incheckning av tillgång',
    'Confirm_Accessory_Checkin' => 'Bekräfta incheckning av tillbehör',
    'Confirm_accessory_delivery' => 'Leveransbekräftelse för tillbehör',
    'Confirm_license_delivery' => 'Leveransbekräftelse för licens',
    'Confirm_asset_delivery' => 'Leveransbekräftelse för tillgång',
    'Confirm_consumable_delivery' => 'Leveransbekräftelse för förbrukningsmaterial',
    'current_QTY' => 'Nuvarande antal',
    'Days' => 'dagar',
    'days' => 'dagar',
    'expecting_checkin_date' => 'Förväntat incheckningsdatum:',
    'expires' => 'Utgår',
    'Expiring_Assets_Report' => 'Rapport över tillgångar med förfallodatum.',
    'Expiring_Licenses_Report' => 'Rapport över licenser med förfallodatum.',
    'hello' => 'Hallå',
    'hi' => 'Hej',
    'i_have_read' => 'Jag har läst och godkänt användarvillkoren och har fått den här produkten.',
    'item' => 'Artikel:',
    'Item_Request_Canceled' => 'Artikelförfrågan annulleras',
    'Item_Requested' => 'Artikel som begärs',
    'link_to_update_password' => 'Vänligen klicka på följande länk för att uppdatera ditt: webblösenord:',
    'login_first_admin' => 'Logga in på din nya Snipe-IT-installation med hjälp av inloggningsuppgifterna nedan:',
    'login' => 'Logga in:',
    'Low_Inventory_Report' => 'Meddelande om lågt lagersaldo',
    'min_QTY' => 'Min. antal',
    'name' => 'namn',
    'new_item_checked' => 'En ny artikel har blivit utcheckad i ditt namn, se detaljer nedan.',
    'password' => 'Lösenord:',
    'password_reset' => 'Lösenordsåterställning',

    'read_the_terms' => 'Läs användarvillkoren nedan.',
    'read_the_terms_and_click' => 'Läs användarvillkoren nedan och klicka på länken längst ner för att bekräfta att du läser och godkänner villkoren för användning och har fått tillgången.',
    'requested' => 'Begärda:',
    'reset_link' => 'Länk för att återställa ditt lösenord',
    'reset_password' => 'Klicka här för att återställa ditt lösenord:',
    'serial' => 'Serienummer',
    'supplier' => 'Leverantör',
    'tag' => 'Tagg',
    'test_email' => 'Testa e-post från Snipe-IT',
    'test_mail_text' => 'Detta är ett test från Snipe-IT Asset Management System. Om du får detta, så fungerar mailen :)',
    'the_following_item' => 'Följande artikel har blivit incheckad: ',
    'low_inventory_alert' => ':count artikel understiger det lägsta tillåtna lagersaldot eller håller på att ta slut.|:count artiklar understiger det lägsta tillåtna lagersaldot eller håller på att ta slut.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => ':count licens löper ut inom :threshold dagar.|:count licenser löper ut inom :threshold days.',
    'to_reset' => 'För att återställa ditt :web lösenord, fyll i det här formuläret:',
    'type' => 'Typ',
    'upcoming-audits' => 'Det finns :count tillgång som kommer upp för revision inom :threshold days.|Det finns :count tillgångar som kommer upp för revision inom :threshold dagar.',
    'user' => 'Användare',
    'username' => 'Användarnamn',
    'welcome' => 'Välkommen: namn',
    'welcome_to' => 'Välkommen till: web!',
    'your_credentials' => 'Dina Snipe-IT användaruppgifter',
    'Accessory_Checkin_Notification' => 'Tillbehöret har checkats in',
    'Asset_Checkin_Notification' => 'Tillgången har checkats in',
    'License_Checkin_Notification' => 'Licensen har checkats in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'En tillgång som checkas ut till dig kommer att checkas in igen :date',
    'your_assets' => 'Visa dina tillgångar',
];
